@@ -984,7 +984,7 @@ public class RootDocImpl
    private ResolvedImport resolveImport(String importSpecifier)
    {
       ResolvedImport result = resolveImportFileSystem(importSpecifier);
-      if (null == result) {
+      if (null == result && Main.getInstance().isReflectionEnabled()) {
          result = resolveImportReflection(importSpecifier);
       }
       if (null == result) {
@@ -1145,13 +1145,18 @@ public class RootDocImpl
       // use reflection, assume fully qualified class name
 
       if (!unlocatableReflectedClassNames.contains(scheduledClassName)) {
-         try {
-            Class clazz = Class.forName(scheduledClassName);
-            printWarning("Cannot locate class " + scheduledClassName + " on file system, falling back to reflection.");
-            ClassDoc result = new ClassDocReflectedImpl(clazz);
-            return result;
+         if (Main.getInstance().isReflectionEnabled()) {
+            try {
+               Class clazz = Class.forName(scheduledClassName);
+               printWarning("Cannot locate class " + scheduledClassName + " on file system, falling back to reflection.");
+               ClassDoc result = new ClassDocReflectedImpl(clazz);
+               return result;
+            }
+            catch (Throwable ignore) {
+               unlocatableReflectedClassNames.add(scheduledClassName);
+            }
          }
-         catch (Throwable ignore) {
+         else {
             unlocatableReflectedClassNames.add(scheduledClassName);
          }
       }
